@@ -441,10 +441,10 @@ class Column(Rect2D):
 
 
 if __name__ == '__main__':
-    img1 = Image2D('/media/D/Sample_images/sample_images_PA/trash_test_mem/counter/00.png')
-    img2 = Image2D('/media/D/Sample_images/sample_images_PA/trash_test_mem/counter/01.png')
-    img3 = Image2D('/media/D/Sample_images/sample_images_PA/trash_test_mem/counter/02.png')
-    img4 = Image2D('/media/D/Sample_images/sample_images_PA/trash_test_mem/counter/03.png')
+    img1 = Image2D('/D/Sample_images/sample_images_PA/trash_test_mem/counter/00.png')
+    img2 = Image2D('/D/Sample_images/sample_images_PA/trash_test_mem/counter/01.png')
+    img3 = Image2D('/D/Sample_images/sample_images_PA/trash_test_mem/counter/02.png')
+    img4 = Image2D('/D/Sample_images/sample_images_PA/trash_test_mem/counter/03.png')
     result = img1 | img2
 
     print(result)
